Coerce an IddObject into an empty object of current class in a character vector format. It is formatted exactly the same as in IDF Editor.
# S3 method for class 'IddObject'
as.character(
x,
comment = NULL,
leading = 4L,
sep_at = 29L,
all = FALSE,
field = TRUE,
...
)An IddObject object.
A character vector to be used as comments of returned string
format object. If NULL, no comments are inserted. Default: NULL.
Leading spaces added to each field. Default: 4.
The character width to separate value string and field string.
Default: 29 which is the same as IDF Editor.'
If TRUE, all fields in current class are returned, otherwise
only minimum fields are returned.
If FALSE, field names will not be included as comments.
Default: TRUE.
Further arguments passed to or from other methods.
A character vector.
if (FALSE) { # \dontrun{
as.character(use_idd(8.8, download = "auto")$Materal, leading = 0)
} # }