Configure which version of EnergyPlus to use

use_eplus(eplus)

eplus_config(ver)

avail_eplus()

is_avail_eplus(ver)

locate_eplus(dirs = NULL)

Arguments

eplus

An acceptable EnergyPlus version or an EnergyPlus installation path.

ver

An acceptable EnergyPlus version.

dirs

A character vector of extra locations to search for EnergyPlus installations. Each entry can be either an EnergyPlus installation directory, or a parent directory that contains installations using standard EnergyPlus directory names. Default: NULL.

Value

  • For use_eplus() and eplus_config(), an (invisible for use_eplus()) list of three contains EnergyPlus version, directory and EnergyPlus executable. version of EnergyPlus;

  • For avail_eplus(), a numeric_version vector or NULL if no available EnergyPlus is found;

  • For is_avis_avail_eplus(), a scalar logical vector.

Details

use_eplus() adds an EnergyPlus version into the EnergyPlus version cache in eplusr. That cache will be used to get corresponding Idd object when parsing IDF files and call corresponding EnergyPlus to run models.

eplus_config() returns the a list of configure data of specified version of EnergyPlus. If no data found, eplusr will try to locate that version in the default installation locations and extra locations set via the base R option eplusr.eplus_dirs. If still no data is found, an empty list will be returned.

avail_eplus() returns all versions of available EnergyPlus. The first call will locate EnergyPlus installations in default installation locations and extra locations set via options(eplusr.eplus_dirs = ...).

locate_eplus() re-searches all EnergyPlus installations at the default locations and any extra dirs, and returns versions of EnergyPlus it finds. Extra search locations can also be configured for the session using options(eplusr.eplus_dirs = ...).

is_avail_eplus() checks if the specified version of EnergyPlus is available or not.

See also

download_eplus() and install_eplus() for downloading and installing EnergyPlus

Examples

if (FALSE) { # \dontrun{
# add specific version of EnergyPlus
use_eplus("8.9")
use_eplus("8.8.0")

# get configure data of specific EnergyPlus version if avaiable
eplus_config("8.6")
} # }

# get all versions of avaiable EnergyPlus
avail_eplus()
#> [1] ‘22.2.0’ ‘26.1.0’

# check if specific version of EnergyPlus is available
is_avail_eplus("8.5")
#> [1] FALSE
is_avail_eplus("8.8")
#> [1] FALSE